@@ -31,6 +31,12 @@ class SyncSpeechByCombinationRequest(RpcRequest):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
+	def get_SpeechId(self):
+		return self.get_body_params().get('SpeechId')
+
+	def set_SpeechId(self,SpeechId):
+		self.add_body_params('SpeechId', SpeechId)
+
 	def get_AudioFormat(self):
 		return self.get_body_params().get('AudioFormat')
 
